==> fsl_5.0.4.orig.tar.gz: fsl-5.0.4.orig/src/misc_c/ztop.cc <==
/* {{{ copyright */

/*  ztop - convert a single z value into p

    Stephen Smith, FMRIB Image Analysis Group

    Copyright (C) 2002 University of Oxford  */

/*  Part of FSL - FMRIB's Software Library
    http://www.fmrib.ox.ac.uk/fsl
    fsl@fmrib.ox.ac.uk
    
    Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
    Imaging of the Brain), Department of Clinical Neurology, Oxford
    University, Oxford, UK
    
    
    LICENCE
    
    FMRIB Software Library, Release 5.0 (c) 2012, The University of
    Oxford (the "Software")
    
    The Software remains the property of the University of Oxford ("the
    University").
    
    The Software is distributed "AS IS" under this Licence solely for
    non-commercial use in the hope that it will be useful, but in order
    that the University as a charitable foundation protects its assets for
    the benefit of its educational and research purposes, the University
    makes clear that no condition is made or to be implied, nor is any
    warranty given or to be implied, as to the accuracy of the Software,
    or that it will be suitable for any particular purpose or for use
    under any specific conditions. Furthermore, the University disclaims
    all responsibility for the use which is made of the Software. It
    further disclaims any liability for the outcomes arising from using
    the Software.
    
    The Licensee agrees to indemnify the University and hold the
    University harmless from and against any and all claims, damages and
    liabilities asserted by third parties (including claims for
    negligence) which arise directly or indirectly from the use of the
    Software or the sale of any products based on the Software.
    
    No part of the Software may be reproduced, modified, transmitted or
    transferred in any form or by any means, electronic or mechanical,
    without the express permission of the University. The permission of
    the University is not required if the said reproduction, modification,
    transmission or transference is done without financial return, the
    conditions of this Licence are imposed upon the receiver of the
    product, and all original and amended source code is included in any
    transmitted product. You may be held legally responsible for any
    copyright infringement that is caused or encouraged by your failure to
    abide by these terms and conditions.
    
    You are not permitted under this Licence to use this Software
    commercially. Use for which any financial return is received shall be
    defined as commercial use, and includes (1) integration of all or part
    of the source code or the Software into a product for sale or license
    by or on behalf of Licensee to third parties or (2) use of the
    Software or any derivative of it for research with the final aim of
    developing software products for sale or license to a third party or
    (3) use of the Software or any derivative of it for research with the
    final aim of developing non-software products for sale or license to a
    third party, or (4) use of the Software to provide any service to an
    external organisation for which payment is received. If you are
    interested in using the Software commercially, please contact Isis
    Innovation Limited ("Isis"), the technology transfer company of the
    University, to negotiate a licence. Contact details are:
    innovation@isis.ox.ac.uk quoting reference DE/9564. */

/* }}} */
/* {{{ defines */

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "libprob.h"

#define MINP 1e-15

using namespace MISCMATHS;

/* }}} */
/* {{{ usage */

void usage(void)
{
  printf("Usage: ztop <z> [-2]\n");
  printf("-2 : use 2-tailed conversion (default is 1-tailed)\n");
  exit(1);
}

/* }}} */

int main(int argc,char *argv[])
{
  int i, twotailed=0;
  double p, z;

  if (argc<2)
    usage();

  z=atof(argv[1]);

  /* {{{ process args */

for (i=2; i<argc; i++)
{
  if (!strcmp(argv[i], "-2"))
    twotailed=1;

  else
    usage();
}

/* }}} */

  p=1-ndtr(z);

  if (twotailed)
    p*=2;
  
  if (p>0.0001) 
    printf("%f\n",p);
  else
    printf("%e\n",p);

  return(0);
}

==> fsl_5.0.8.orig.tar.gz: fsl-5.0.8.orig/src/misc_c/ztop.cc <==
/*  ztop - convert a single z value into p

    Stephen Smith, Tom Nichols and Matthew Webster, FMRIB Image Analysis Group

    Copyright (C) 2002-2014 University of Oxford  */

/*  Part of FSL - FMRIB's Software Library
    http://www.fmrib.ox.ac.uk/fsl
    fsl@fmrib.ox.ac.uk
    
    Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
    Imaging of the Brain), Department of Clinical Neurology, Oxford
    University, Oxford, UK
    
    
    LICENCE
    
    FMRIB Software Library, Release 5.0 (c) 2012, The University of
    Oxford (the "Software")
    
    The Software remains the property of the University of Oxford ("the
    University").
    
    The Software is distributed "AS IS" under this Licence solely for
    non-commercial use in the hope that it will be useful, but in order
    that the University as a charitable foundation protects its assets for
    the benefit of its educational and research purposes, the University
    makes clear that no condition is made or to be implied, nor is any
    warranty given or to be implied, as to the accuracy of the Software,
    or that it will be suitable for any particular purpose or for use
    under any specific conditions. Furthermore, the University disclaims
    all responsibility for the use which is made of the Software. It
    further disclaims any liability for the outcomes arising from using
    the Software.
    
    The Licensee agrees to indemnify the University and hold the
    University harmless from and against any and all claims, damages and
    liabilities asserted by third parties (including claims for
    negligence) which arise directly or indirectly from the use of the
    Software or the sale of any products based on the Software.
    
    No part of the Software may be reproduced, modified, transmitted or
    transferred in any form or by any means, electronic or mechanical,
    without the express permission of the University. The permission of
    the University is not required if the said reproduction, modification,
    transmission or transference is done without financial return, the
    conditions of this Licence are imposed upon the receiver of the
    product, and all original and amended source code is included in any
    transmitted product. You may be held legally responsible for any
    copyright infringement that is caused or encouraged by your failure to
    abide by these terms and conditions.
    
    You are not permitted under this Licence to use this Software
    commercially. Use for which any financial return is received shall be
    defined as commercial use, and includes (1) integration of all or part
    of the source code or the Software into a product for sale or license
    by or on behalf of Licensee to third parties or (2) use of the
    Software or any derivative of it for research with the final aim of
    developing software products for sale or license to a third party or
    (3) use of the Software or any derivative of it for research with the
    final aim of developing non-software products for sale or license to a
    third party, or (4) use of the Software to provide any service to an
    external organisation for which payment is received. If you are
    interested in using the Software commercially, please contact Isis
    Innovation Limited ("Isis"), the technology transfer company of the
    University, to negotiate a licence. Contact details are:
    innovation@isis.ox.ac.uk quoting reference DE/9564. */

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <cmath>
#include "libprob.h"
#include <algorithm>

#define MINP 1e-15
using namespace std;
using namespace MISCMATHS;

/* }}} */
/* {{{ usage */

void usage(void)
{
  printf("Usage: ztop <z> [-2] [-g <number_of_resels>]\n");
  printf("-2 : use 2-tailed conversion (default is 1-tailed)\n");
  printf("-g : use GRF maximum-height theory instead of Gaussian pdf\n");
  exit(1);
}

/* }}} */

int main(int argc,char *argv[])
{
  int i, twotailed=0, grf=0;
  double p, z, nresels=0;

  if (argc<2)
    usage();

  z=atof(argv[1]);

  /* {{{ process args */

for (i=2; i<argc; i++)
{
  if (!strcmp(argv[i], "-2"))
    twotailed=1;
  else if (!strcmp(argv[i], "-g"))
    {
      grf=1;
      i++;
      if (argc<i+1)
	{
	  printf("Error: no value given following -g\n");
	  usage();
	}
      nresels=atof(argv[i]);
    }

  else
    usage();
}

/* }}} */

  if (twotailed)
    z=fabs(z);

  if (grf) {
    if (z<2)
      p=1; /* Below z of 2 E(EC) becomes non-monotonic */
    else
      p = nresels * 0.11694 * exp(-0.5*z*z)*(z*z-1);  /* 0.11694 = (4ln2)^1.5 / (2pi)^2 */
  }  else {
    p=1-ndtr(z);
  }

  if (twotailed)
    p*=2;

  p=min(p,1.0);

  if (p>0.0001) 
    printf("%f\n",p);
  else
    printf("%e\n",p);

  return(0);
}
